@@ -245,9 +245,9 @@ class LidarScene:
 
                 # Save frame images
                 for camera_id, image in frame.images.items():
-                    if not image.file:
+                    if not image.image_path:
                         assert NotImplemented('Only file-imported Images supported')
-                    out.write(image.file, 'image-%s-%s.jpg' % (camera_id, frame.id))
+                    out.write(image.image_path, 'image-%s-%s.jpg' % (camera_id, frame.id))
         print('Scene saved.')
 
     def create_task(self, template: Dict = None, task_type: str = 'lidarannotation') -> Task:
