@@ -6,41 +6,11 @@ import ujson
 from scaleapi import ScaleClient, Task
 
 from .scene import LidarScene
-
-
-def parse_xyz(obj):
-    return np.array([obj['x'], obj['y'], obj['z']])
-
-
-def parse_cuboid_frame(frame):
-    return np.array([parse_xyz(p) for p in [c['position'] for c in frame['cuboids']]])
-
-
-def read_cuboid_points(filename):
-    # Read from result file
-    with open(filename, 'r') as json_file:
-        return np.array([parse_cuboid_frame(frame) for frame in ujson.load(json_file)])
-
-
-def get_api_client() -> ScaleClient:
-    assert os.getenv('SCALE_API_KEY'), 'No API key, please set SCALE_API_KEY environment variable'
-    return ScaleClient(os.getenv('SCALE_API_KEY'))
-
-
-def get_default_template():
-    return {
-        'task_id': None,
-        'callback_url': 'http://example.com',
-        'instruction': 'Please label all objects',
-        'labels': [
-            'Object'
-        ],
-        'meters_per_unit': 1,
-        'max_distance_meters': 20
-    }
-
+from .helper import parse_xyz, parse_cuboid_frame, read_cuboid_points, get_api_client, get_default_template
 
 class LidarAnnotationTask(Task):
+    """Lidar annotation Task object
+    """
     scene: LidarScene = None
 
     def __init__(self, param_dict, client):
@@ -48,6 +18,18 @@ class LidarAnnotationTask(Task):
 
     @staticmethod
     def from_scene(scene: LidarScene, template=None, client=None):
+        """Load scene data and convert it into a LidarAnnotation Task format
+
+        :param scene: Scene to load
+        :type scene: LidarScene
+        :param template: Template/payload to use get fetch the Scale API
+        :type template: dict
+        :param client: ScaleClient object, by default it will load your SCALE_API_KEY from you env vars and set a client automatically.
+        :type client: scaleapi.ScaleClient
+        :returns: LidarAnnotationTask object
+        :rtype: LidarAnnotationTask
+
+        """
         assert scene.public_url, 'No public URL on scene, please upload or save the scene first'
 
         # Get client using environ api key
@@ -74,17 +56,37 @@ class LidarAnnotationTask(Task):
         return LidarAnnotationTask(param_dict, client)
 
     @staticmethod
-    def from_id(task_id):
+    def from_id(task_id:str):
+        """Get LidarAnnotation task from a task id
+
+        :param task_id: Task id
+        :type task_id: str
+        :returns: LidarAnnotationTask object created based on the task id data
+        :rtype: LidarAnnotationTask
+
+        """
         task = get_api_client().fetch_task(task_id)
         return LidarAnnotationTask(task.param_dict, task.client)
 
     def get_annotations(self):
+        """Get annotations/response from a completed LidarAnnotation task
+
+        :returns: Annotations
+        :rtype: dict
+
+        """
         assert 'response' in self.param_dict, 'Task without response'
         url = self.param_dict['response']['annotations']['url']
         response = requests.get(url)
         return ujson.loads(response.text)
 
     def get_cuboid_positions_by_frame(self):
+        """Get a list of each cuboid position in each frames (from a completed task)
+
+        :returns: List of cuboids positions
+        :rtype: list
+
+        """
         annotations = self.get_annotations()
         return np.array([
             np.array([
@@ -94,8 +96,16 @@ class LidarAnnotationTask(Task):
             for frame in annotations
         ])
 
-    def publish(self, task_type='lidarannotation'):
-        task = self.client.create_task(task_type, **self.param_dict)
+    def publish(self, task_type: str='lidarannotation'):
+        """Publish/create a task, request Scale API with the LidarAnnotation data
+
+        :param task_type: Task type to create, default ``lidarannotation``
+        :type task_type: str
+        :returns: Task object creation from the response of the API call
+        :rtype: scaleapi.Task
+
+        """
+        task = self.client.create_task('lidarannotation', **self.param_dict)
         print('Task created: %s' % task)
         return task
 
@@ -108,6 +118,18 @@ class LidarTopDownTask(Task):
 
     @staticmethod
     def from_scene(scene: LidarScene, template=None, client=None):
+        """Load scene data and convert it into a LidarTopDown Task format
+
+        :param scene: Scene to load
+        :type scene: LidarScene
+        :param template: Template/payload to use get fetch the Scale API
+        :type template: dict
+        :param client: ScaleClient object, by default it will load your SCALE_API_KEY from you env vars and set a client automatically.
+        :type client: scaleapi.ScaleClient
+        :returns: LidarTopDownTask object
+        :rtype: LidarTopDownTask
+
+        """
         assert scene.public_url, 'No public URL on scene, please upload or save the scene first'
 
         # Get client using environ api key
@@ -134,16 +156,32 @@ class LidarTopDownTask(Task):
         return LidarTopDownTask(param_dict, client)
 
     @staticmethod
-    def from_id(task_id):
+    def from_id(task_id:str):
+        """Get LidarTopDown task from a task id
+
+        :param task_id: Task id
+        :type task_id: str
+        :returns: LidarTopDownTask object created based on the task id data
+        :rtype: LidarTopDownTask
+
+        """
         task = get_api_client().fetch_task(task_id)
         return LidarTopDownTask(task.param_dict, task.client)
 
-    def publish(self, task_type='lidartopdown'):
-        task = self.client.create_task(task_type, **self.param_dict)
+    def publish(self, task_type: str='lidartopdown'):
+        """Publish/create a task, request Scale API with the LidarTopDown data
+
+        :param task_type: Task type to create, default ``lidartopdown``
+        :type task_type: str
+        :returns: Task object creation from the response of the API call
+        :rtype: scaleapi.Task
+
+        """
+        task = self.client.create_task('lidartopdown', **self.param_dict)
         print('Task created: %s' % task)
         return task
 
-class LidarSegmentation(Task):
+class LidarSegmentationTask(Task):
     scene: LidarScene = None
 
     def __init__(self, param_dict, client):
@@ -151,6 +189,18 @@ class LidarSegmentation(Task):
 
     @staticmethod
     def from_scene(scene: LidarScene, template=None, client=None):
+        """Load scene data and convert it into a LidarSegmentation Task format
+
+        :param scene: Scene to load
+        :type scene: LidarScene
+        :param template: Template/payload to use get fetch the Scale API
+        :type template: dict
+        :param client: ScaleClient object, by default it will load your SCALE_API_KEY from you env vars and set a client automatically.
+        :type client: scaleapi.ScaleClient
+        :returns: LidarSegmentationTask object
+        :rtype: LidarSegmentationTask
+
+        """
         assert scene.public_url, 'No public URL on scene, please upload or save the scene first'
 
         # Get client using environ api key
@@ -177,11 +227,27 @@ class LidarSegmentation(Task):
         return LidarSegmentation(param_dict, client)
 
     @staticmethod
-    def from_id(task_id):
+    def from_id(task_id:str):
+        """Get LidarSegmentation task from a task id
+
+        :param task_id: Task id
+        :type task_id: str
+        :returns: LidarSegmentationTask object created based on the task id data
+        :rtype: LidarSegmentationTask
+
+        """
         task = get_api_client().fetch_task(task_id)
         return LidarSegmentation(task.param_dict, task.client)
 
-    def publish(self, task_type='lidarsegmentation'):
-        task = self.client.create_task(task_type, **self.param_dict)
+    def publish(self, task_type: str='lidarsegmentation'):
+        """Publish/create a task, request Scale API with the LidarSegmentation data
+
+        :param task_type: Task type to create, default ``lidarsegmentation``
+        :type task_type: str
+        :returns: Task object creation from the response of the API call
+        :rtype: scaleapi.Task
+
+        """
+        task = self.client.create_task('lidarsegmentation', **self.param_dict)
         print('Task created: %s' % task)
         return task
